import * as vue from 'vue';
import vue__default, { ComponentOptions, VueConstructor, ComponentInstance } from 'vue';

declare const VISIBLE_KEY = "update:visible";

type DefaultRecord = Record<string, any>;
type DefaultFunction = (...args: any[]) => void;
type PropsOptions = {
    visible?: boolean;
    title?: string;
    width?: string;
    fullscreen?: boolean;
    top?: string;
    modal?: boolean;
    'modal-append-to-body'?: boolean;
    'append-to-body'?: boolean;
    'lock-scroll'?: boolean;
    'custom-class'?: string;
    'close-on-click-modal'?: boolean;
    'close-on-press-escape'?: boolean;
    'show-close'?: boolean;
    'before-close'?: (done: () => void) => void;
    center?: boolean;
    'destroy-on-close'?: boolean;
};
type EventOptions = {
    open?: () => void;
    opened?: () => void;
    close?: () => void;
    closed?: () => void;
    [VISIBLE_KEY]?: (value: boolean) => void;
};
type UserOptions = PropsOptions & EventOptions;
type VComponentOptions = ComponentOptions<vue__default>;
interface SingleSlotOptions {
    component: VComponentOptions;
    propsData?: DefaultRecord;
}
type SlotOptions = VComponentOptions | SingleSlotOptions;
interface SlotsOptions {
    default?: SlotOptions;
    title?: SlotOptions;
    footer?: SlotOptions;
}
type ContentOptions = VComponentOptions | SlotsOptions;
interface DialogHandler {
    (content: ContentOptions, options?: UserOptions): Promise<any>;
}
declare module 'vue/types/vue' {
    interface Vue {
        $dialog: DialogHandler;
    }
}

declare function Dialog(Vue: VueConstructor): {
    new (options?: UserOptions): {
        globalOptions: UserOptions;
        options: UserOptions;
        vm: ComponentInstance | null;
        content?: ContentOptions | undefined;
        resolve?: DefaultFunction | undefined;
        reject?: DefaultFunction | undefined;
        dialog(content: ContentOptions, options?: UserOptions): Promise<any>;
        getInstance(): ComponentInstance;
        createComponent(): VComponentOptions;
        destroy(): boolean;
    };
};
declare namespace Dialog {
    var install: (Vue: VueConstructor<vue.default<Record<string, any>, Record<string, any>, never, never, (event: string, ...args: any[]) => vue.default<Record<string, any>, Record<string, any>, never, never, any>>>, options?: UserOptions) => void;
}

export { Dialog as default };
